@@ -1,21 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2010 by Peter Penz <peter.penz19@gmail.com>             *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
- ***************************************************************************/
+/*
+ *   SPDX-FileCopyrightText: 2010 Peter Penz <peter.penz19@gmail.com>
+ *
+ *   SPDX-License-Identifier: GPL-2.0-or-later
+ */
 
 #include "kio_filenamesearch.h"
 
@@ -32,7 +19,12 @@
 #include <QDBusInterface>
 #include <KLocalizedString>
 
-Q_LOGGING_CATEGORY(KIO_FILENAMESEARCH, "kio_filenamesearch")
+// Pseudo plugin class to embed meta data
+class KIOPluginForMetaData : public QObject
+{
+    Q_OBJECT
+    Q_PLUGIN_METADATA(IID "org.kde.kio.slave.filenamesearch" FILE "filenamesearch.json")
+};
 
 FileNameSearchProtocol::FileNameSearchProtocol(const QByteArray &pool, const QByteArray &app)
     : SlaveBase("search", pool, app)
@@ -82,7 +74,7 @@ void FileNameSearchProtocol::listDir(const QUrl &url)
     if (urlQuery.queryItemValue("checkContent") == QStringLiteral("yes")) {
         validator = [pattern](const KFileItem &item) -> bool {
             return item.determineMimeType().inherits(QStringLiteral("text/plain")) &&
-                   contentContainsPattern(item.url(), pattern);
+            contentContainsPattern(item.url(), pattern);
         };
     } else {
         validator = [pattern](const KFileItem &item) -> bool {
@@ -98,8 +90,8 @@ void FileNameSearchProtocol::listDir(const QUrl &url)
 }
 
 void FileNameSearchProtocol::searchDirectory(const QUrl &directory,
-                                             const std::function<bool(const KFileItem &)> &itemValidator,
-                                             QSet<QString> &iteratedDirs)
+        const std::function<bool(const KFileItem &)> &itemValidator,
+        QSet<QString> &iteratedDirs)
 {
     if (directory.path() == QStringLiteral("/proc")) {
         // Don't try to iterate the /proc directory of Linux
@@ -204,3 +196,5 @@ extern "C" int Q_DECL_EXPORT kdemain(int argc, char **argv)
 
     return 0;
 }
+
+#include "kio_filenamesearch.moc"
