@@ -1,21 +1,9 @@
 /*
  *  Main implementation for KIO-MTP
- *  Copyright (C) 2012  Philipp Schmidt <philschmidt@gmx.net>
- *  Copyright (C) 2018 Andreas Krutzler <andreas.krutzler@gmx.net>
+ *  SPDX-FileCopyrightText: 2012 Philipp Schmidt <philschmidt@gmx.net>
+ *  SPDX-FileCopyrightText: 2018 Andreas Krutzler <andreas.krutzler@gmx.net>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #ifndef KIO_MTP_H
@@ -34,7 +22,6 @@
 // #include <QCache>
 
 #include <QUrl>
-#include <QLoggingCategory>
 
 #define MAX_XFER_BUF_SIZE 16348
 #define KIO_MTP 7000
@@ -46,11 +33,9 @@ class KMTPFile;
 
 using namespace KIO;
 
-Q_DECLARE_LOGGING_CATEGORY(LOG_KIO_MTP)
-
 class MTPSlave : public QObject, public KIO::SlaveBase
 {
-Q_OBJECT
+    Q_OBJECT
 
 public:
     /*
@@ -69,7 +54,7 @@ public:
     void del(const QUrl &url, bool) override;
     void rename(const QUrl &src, const QUrl &dest, JobFlags flags) override;
 
-// private slots:
+// private Q_SLOTS:
 //
 //     void test();
 
