@@ -1,6 +1,6 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
-    SPDX-FileCopyrightText: 2000 Caldera Systems, Inc.
+    SPDX-FileCopyrightText: 2000 Caldera Systems Inc.
     SPDX-FileCopyrightText: 2018-2020 Harald Sitter <sitter@kde.org>
     SPDX-FileContributor: Matthew Peterson <mpeterson@caldera.com>
 */
@@ -8,8 +8,14 @@
 #include "kio_smb.h"
 #include "smburl.h"
 
+#include <kdnssd_version.h>
+#if KDNSSD_VERSION >= QT_VERSION_CHECK(5, 84, 0)
+#include <KDNSSD/RemoteService>
+#include <KDNSSD/ServiceBrowser>
+#else
 #include <DNSSD/RemoteService>
 #include <DNSSD/ServiceBrowser>
+#endif
 #include <KIO/Job>
 #include <KLocalizedString>
 
@@ -333,10 +339,10 @@ SMBSlave::SMBError SMBSlave::errnumToKioError(const SMBUrl &url, const int errNu
     default:
         return SMBError {
             ERR_INTERNAL,
-                    i18nc("%1 is an error number, %2 either a pretty string or the number",
-                          "Unknown error condition: [%1] %2",
-                          QString::number(errNum),
-                          QString::fromLocal8Bit(strerror(errNum)))
+            i18nc("%1 is an error number, %2 either a pretty string or the number",
+                  "Unknown error condition: [%1] %2",
+                  QString::number(errNum),
+                  QString::fromLocal8Bit(strerror(errNum)))
         };
     }
 }
