@@ -3,26 +3,12 @@
  *
  * Comic Book Thumbnailer for KDE 4 v0.1
  * Creates cover page previews for comic-book files (.cbr/z/t).
- * Copyright (c) 2009 Harsh J <harsh@harshj.com>
+ * SPDX-FileCopyrightText: 2009 Harsh J <harsh@harshj.com>
  *
  * Some code borrowed from Okular's comicbook generators,
  * by Tobias Koenig <tokoe@kde.org>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
 // comiccreator.cpp
@@ -70,8 +56,8 @@ bool ComicCreator::create(const QString& path, int width, int height, QImage& im
         // ZIP archive.
         cover = extractArchiveImage(path, ZIP);
     } else if (mime.inherits("application/x-cbt") ||
-                mime.inherits("application/x-gzip") ||
-                mime.inherits("application/x-tar")) {
+               mime.inherits("application/x-gzip") ||
+               mime.inherits("application/x-tar")) {
         // TAR archive
         cover = extractArchiveImage(path, TAR);
     } else if (mime.inherits("application/x-cb7") || mime.inherits("application/x-7z-compressed")) {
@@ -99,7 +85,7 @@ void ComicCreator::filterImages(QStringList& entries)
     for (const QString& entry : qAsConst(entries)) {
         // Skip MacOS resource forks
         if (entry.startsWith(QLatin1String("__MACOSX"), Qt::CaseInsensitive) ||
-            entry.startsWith(QLatin1String(".DS_Store"), Qt::CaseInsensitive)) {
+                entry.startsWith(QLatin1String(".DS_Store"), Qt::CaseInsensitive)) {
             continue;
         }
         if (entry.endsWith(QLatin1String(".gif"), Qt::CaseInsensitive) ||
@@ -133,7 +119,7 @@ QImage ComicCreator::extractArchiveImage(const QString& path, const ComicCreator
 
     // Can our archive be opened?
     if (!cArchive->open(QIODevice::ReadOnly)) {
-            return QImage();
+        return QImage();
     }
 
     // Get the archive's directory.
@@ -154,7 +140,7 @@ QImage ComicCreator::extractArchiveImage(const QString& path, const ComicCreator
 
     // Extract the cover file.
     const KArchiveFile *coverFile = static_cast<const KArchiveFile*>
-        (cArchiveDir->entry(entries[0]));
+                                    (cArchiveDir->entry(entries[0]));
     if (!coverFile) {
         return QImage();
     }
@@ -165,15 +151,15 @@ QImage ComicCreator::extractArchiveImage(const QString& path, const ComicCreator
 
 
 void ComicCreator::getArchiveFileList(QStringList& entries, const QString& prefix,
-    const KArchiveDirectory *dir)
+                                      const KArchiveDirectory *dir)
 {
     /// Recursively list all files in the ZIP archive into 'entries'.
     const auto dirEntries = dir->entries();
     for (const QString& entry : dirEntries) {
         const KArchiveEntry *e = dir->entry(entry);
         if (e->isDirectory()) {
-        getArchiveFileList(entries, prefix + entry + '/',
-            static_cast<const KArchiveDirectory*>(e));
+            getArchiveFileList(entries, prefix + entry + '/',
+                               static_cast<const KArchiveDirectory*>(e));
         } else if (e->isFile()) {
             entries.append(prefix + entry);
         }
@@ -210,13 +196,13 @@ QImage ComicCreator::extractRARImage(const QString& path)
 }
 
 QStringList ComicCreator::getRARFileList(const QString& path,
-    const QString& unrarPath)
+        const QString& unrarPath)
 {
     /// Get a verbose unrar listing so we can extract a single file later.
     // CMD: unrar vb /path/to/archive
     QStringList entries;
     runProcess(unrarPath, {"vb", path});
-    entries = QString::fromLocal8Bit(m_stdOut).split('\n', QString::SkipEmptyParts);
+    entries = QString::fromLocal8Bit(m_stdOut).split('\n', Qt::SkipEmptyParts);
     return entries;
 }
 
@@ -235,7 +221,7 @@ QString ComicCreator::unrarPath() const
         proc.start(unrar, {"-version"});
         proc.waitForFinished(-1);
         const QStringList lines = QString::fromLocal8Bit(proc.readAllStandardOutput()).split
-            ('\n', QString::SkipEmptyParts);
+                                  ('\n', Qt::SkipEmptyParts);
         if (!lines.isEmpty()) {
             if (lines.first().startsWith(QLatin1String("RAR ")) || lines.first().startsWith(QLatin1String("UNRAR "))) {
                 return unrar;
